# pyguardian

## Description
pyguardian is a Python library that validates the types of a function's parameters via the `guard decorator`:
```python
@guard(int, int)
def add(a, b):
    return a+b
```

## Installation
```bash
pip install pyguardian
```

## Documentation
[pyguardian documentation](https://github.com/greysonDEV/pyguardian/blob/master/DOCUMENTATION.md)

## License
pyguardian is licensed under the [MIT](https://github.com/greysonDEV/pyguardian/blob/master/LICENSE) License.